summaryrefslogtreecommitdiffstats
path: root/net/http/http_response_info.cc
diff options
context:
space:
mode:
authorbnc <bnc@chromium.org>2014-11-06 17:25:09 -0800
committerCommit bot <commit-bot@chromium.org>2014-11-07 01:26:17 +0000
commit6371af94b25f78f85691e892627a9e88832e2ba0 (patch)
tree2ec073afffc8a4e62f2c15ac90569e524ab58545 /net/http/http_response_info.cc
parent60a7dbf7faabe2a3b8caf306d8d2a01bfdcd5b59 (diff)
downloadchromium_src-6371af94b25f78f85691e892627a9e88832e2ba0.zip
chromium_src-6371af94b25f78f85691e892627a9e88832e2ba0.tar.gz
chromium_src-6371af94b25f78f85691e892627a9e88832e2ba0.tar.bz2
Update ALPN/NPN token from "h2-14" to "h2-15".
HTTP/2 draft-15 was published on 2014-10-27. There are no functional changes concerning the features that are currently implemented in Chromium. See https://tools.ietf.org/wg/httpbis/draft-ietf-httpbis-http2/. This change is parallel to the server side change 79349571 by mlavan. Two separate CLs will accompany this change: * Add HTTP_1_1_REQUIRED error code. This will be silently ignored, as Chromium only speaks HTTP/2 to peer that have explicitly acknowledged their support via ALPN or NPN. * https://crrev.com/711563003 BUG=345769 Review URL: https://codereview.chromium.org/707953002 Cr-Commit-Position: refs/heads/master@{#303150}
Diffstat (limited to 'net/http/http_response_info.cc')
-rw-r--r--net/http/http_response_info.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/net/http/http_response_info.cc b/net/http/http_response_info.cc
index 9569b38..2ec0fb5 100644
--- a/net/http/http_response_info.cc
+++ b/net/http/http_response_info.cc
@@ -396,9 +396,9 @@ std::string HttpResponseInfo::ConnectionInfoToString(
case CONNECTION_INFO_SPDY3:
return "spdy/3";
case CONNECTION_INFO_SPDY4:
// This is the HTTP/2 draft 14 identifier. For internal
// consistency, HTTP/2 is named SPDY4 within Chromium.
- return "h2-14";
+ return "h2-15";
case CONNECTION_INFO_QUIC1_SPDY3:
return "quic/1+spdy/3";
case NUM_OF_CONNECTION_INFOS:
@@ -396,9 +396,9 @@ std::string HttpResponseInfo::ConnectionInfoToString(
return "spdy/3";
case CONNECTION_INFO_SPDY4:
- // This is the HTTP/2 draft 14 identifier. For internal
+ // This is the HTTP/2 draft-15 identifier. For internal
// consistency, HTTP/2 is named SPDY4 within Chromium.